{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan: find (fragmented) genes in short reads",
            "doc": "FragGeneScan is an application for finding (fragmented) genes in short\nreads. It can also be applied to predict prokaryotic genes in incomplete\nassemblies or complete genomes.\n\nFragGeneScan was first released through omics website (http://omics.informatics.indiana.edu/FragGeneScan/)\nin March 2010, where you can find its old releases. FragGeneScan migrated to SourceForge in October, 2013\n(https://sourceforge.net/projects/fraggenescan/).\n\nVersion 1.20 can be downloaded here:\nhttps://sourceforge.net/projects/fraggenescan/files/\n",
            "baseCommand": [],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#FragGeneScan-model.yaml/model",
                            "fields": [
                                {
                                    "name": "#FragGeneScan-model.yaml/model/main",
                                    "type": "File"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_forward",
                                    "type": "File",
                                    "label": "Forward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_backward",
                                    "type": "File",
                                    "label": "Backward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_noncoding",
                                    "type": "File",
                                    "label": "Noncoding probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start",
                                    "type": "File",
                                    "label": "Start probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop",
                                    "type": "File",
                                    "label": "Stop probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start1",
                                    "type": "File",
                                    "label": "Start1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop1",
                                    "type": "File",
                                    "label": "Stop1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/pwm_dist",
                                    "type": "File",
                                    "label": "pwm distribution"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011929"
                            ],
                            "version": [
                                "1.20"
                            ],
                            "package": "fraggenescan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "True if the sequence file has complete genomic sequences\nFalse if the sequence file has short sequence reads\n",
                    "type": "boolean",
                    "inputBinding": {
                        "valueFrom": "${ if (self) {\n     return [ \"-w\", \"1\" ];\n   } else {\n     return [ \"-w\", \"0\" ];\n   }\n }\n"
                    },
                    "id": "#FragGeneScan1_20.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#FragGeneScan1_20.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#FragGeneScan1_20.cwl/sequence"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#FragGeneScan1_20.cwl/threadNumber"
                }
            ],
            "arguments": [
                "mkdir",
                "train",
                ";",
                "ln",
                "-s",
                "$(inputs.model.main.path)",
                "train/model",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_forward.path)",
                "train/gene",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_backward.path)",
                "train/rgene",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_noncoding.path)",
                "train/noncoding",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_start.path)",
                "train/start",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_stop.path)",
                "train/stop",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_start1.path)",
                "train/start1",
                ";",
                "ln",
                "-s",
                "$(inputs.model.prob_stop1.path)",
                "train/stop1",
                ";",
                "ln",
                "-s",
                "$(inputs.model.pwm_dist.path)",
                "train/pwm",
                ";",
                "FragGeneScan",
                "-o",
                "$(runtime.outdir)/predicted_cds",
                "-t",
                "model"
            ],
            "id": "#FragGeneScan1_20.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.faa"
                    },
                    "id": "#FragGeneScan1_20.cwl/predictedCDS"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "InterProScan: protein sequence classifier",
            "doc": "Version 5.21-60 can be downloaded here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToDownload\n\nDocumentation on how to run InterProScan 5 can be found here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToRun\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#InterProScan-apps.yaml/apps",
                            "symbols": [
                                "#InterProScan-apps.yaml/apps/TIGRFAM",
                                "#InterProScan-apps.yaml/apps/SFLD",
                                "#InterProScan-apps.yaml/apps/SUPERFAMILY",
                                "#InterProScan-apps.yaml/apps/Gene3D",
                                "#InterProScan-apps.yaml/apps/Hamap",
                                "#InterProScan-apps.yaml/apps/Coils",
                                "#InterProScan-apps.yaml/apps/ProSiteProfiles",
                                "#InterProScan-apps.yaml/apps/SMART",
                                "#InterProScan-apps.yaml/apps/CDD",
                                "#InterProScan-apps.yaml/apps/PRINTS",
                                "#InterProScan-apps.yaml/apps/PIRSF",
                                "#InterProScan-apps.yaml/apps/ProSitePatterns",
                                "#InterProScan-apps.yaml/apps/Pfam",
                                "#InterProScan-apps.yaml/apps/ProDom",
                                "#InterProScan-apps.yaml/apps/MobiDBLite"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#InterProScan-protein_formats.yaml/protein_formats",
                            "symbols": [
                                "#InterProScan-protein_formats.yaml/protein_formats/TSV",
                                "#InterProScan-protein_formats.yaml/protein_formats/XML",
                                "#InterProScan-protein_formats.yaml/protein_formats/GFF3"
                            ]
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005829"
                            ],
                            "version": [
                                "5.21-60"
                            ],
                            "package": "interproscan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "id": "#InterProScan5.21-60.cwl/applications"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#InterProScan5.21-60.cwl/proteinFile"
                }
            ],
            "baseCommand": "interproscan.sh",
            "arguments": [
                {
                    "valueFrom": "i5_annotations",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "TSV",
                    "prefix": "--formats"
                },
                "--disable-precalc",
                "--goterms",
                "--pathways",
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tempdir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "i5_annotations"
                    },
                    "id": "#InterProScan5.21-60.cwl/i5Annotations"
                }
            ],
            "id": "#InterProScan5.21-60.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#biom-convert-table.yaml/table_type",
                            "label": "The type of the table to produce",
                            "symbols": [
                                "#biom-convert-table.yaml/table_type/OTU table",
                                "#biom-convert-table.yaml/table_type/Pathway table",
                                "#biom-convert-table.yaml/table_type/Function table",
                                "#biom-convert-table.yaml/table_type/Ortholog table",
                                "#biom-convert-table.yaml/table_type/Gene table",
                                "#biom-convert-table.yaml/table_type/Metabolite table",
                                "#biom-convert-table.yaml/table_type/Taxon table",
                                "#biom-convert-table.yaml/table_type/Table"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://doi.org/10.1186/2047-217X-1-7"
                            ],
                            "version": [
                                "2.1.6"
                            ],
                            "package": "biom-format"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-convert.cwl/biom"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as HDF5-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-hdf5"
                    },
                    "id": "#biom-convert.cwl/hdf5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The observation metadata to include from the input BIOM table file when\ncreating a tsv table file. By default no observation metadata will be\nincluded.\n",
                    "inputBinding": {
                        "prefix": "--header-key"
                    },
                    "id": "#biom-convert.cwl/header_key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as JSON-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-json"
                    },
                    "id": "#biom-convert.cwl/json"
                },
                {
                    "type": [
                        "null",
                        "#biom-convert-table.yaml/table_type"
                    ],
                    "inputBinding": {
                        "prefix": "--table-type"
                    },
                    "id": "#biom-convert.cwl/table_type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as TSV-formatted (classic) table.",
                    "inputBinding": {
                        "prefix": "--to-tsv"
                    },
                    "id": "#biom-convert.cwl/tsv"
                }
            ],
            "baseCommand": [
                "biom",
                "convert"
            ],
            "arguments": [
                {
                    "valueFrom": "result",
                    "prefix": "--output-fp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "result"
                    },
                    "id": "#biom-convert.cwl/result"
                }
            ],
            "id": "#biom-convert.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "types": [
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://doi.org/10.1186/2047-217X-1-7"
                            ],
                            "version": [
                                "2.1.6"
                            ],
                            "package": "biom-format"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_3746",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-summarize_table.cwl/biom"
                }
            ],
            "baseCommand": [
                "biom",
                "summarize-table"
            ],
            "arguments": [
                {
                    "valueFrom": "otu_table_summary.txt",
                    "prefix": "--output-fp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "otu_table_summary.txt"
                    },
                    "id": "#biom-summarize_table.cwl/otu_table_summary"
                }
            ],
            "id": "#biom-summarize_table.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "replace problem characters from FASTA headers with dashes",
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#clean_fasta_headers.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": [
                "tr",
                " /|<_;#",
                "-------"
            ],
            "stdout": "$(inputs.sequences.nameroot).cleaned.fasta",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#clean_fasta_headers.cwl/sequences_with_cleaned_headers",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.nameroot).cleaned.fasta"
                    }
                }
            ],
            "id": "#clean_fasta_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#collate_unique_SSU_headers.cwl/hits"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sorted_uniq_names",
                    "id": "#collate_unique_SSU_headers.cwl/unique_hits"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/hits",
                            "id": "#collate_unique_SSU_headers.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "scatter": "#collate_unique_SSU_headers.cwl/extract_coord_lines/summary",
                    "out": [
                        "#collate_unique_SSU_headers.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n",
                                "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1}"
                        ],
                        "stdout": "names",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names/names",
                                "outputBinding": {
                                    "glob": "names"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/extract_coord_lines/coord_lines",
                            "id": "#collate_unique_SSU_headers.cwl/extract_names/coordinate_lines"
                        }
                    ],
                    "scatter": "#collate_unique_SSU_headers.cwl/extract_names/coordinate_lines",
                    "out": [
                        "#collate_unique_SSU_headers.cwl/extract_names/names"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/extract_names"
                },
                {
                    "run": {
                        "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "inputBinding": {
                                    "position": 1
                                },
                                "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names/names"
                            }
                        ],
                        "baseCommand": [
                            "sort",
                            "--unique"
                        ],
                        "stdout": "sorted_uniq_names",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names/sorted_uniq_names",
                                "outputBinding": {
                                    "glob": "sorted_uniq_names"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/extract_names/names",
                            "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/names"
                        }
                    ],
                    "out": [
                        "#collate_unique_SSU_headers.cwl/sort_uniq_names/sorted_uniq_names"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names"
                }
            ],
            "id": "#collate_unique_SSU_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "drop short seqs",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "label": "discard if number of bases is less than this amount",
                    "id": "#discard_short_seqs.cwl/minimum_length"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#discard_short_seqs.cwl/sequences"
                }
            ],
            "baseCommand": [
                "python"
            ],
            "arguments": [
                {
                    "valueFrom": "from Bio import SeqIO\ninput_seq_iterator = SeqIO.parse(\"$(inputs.sequences.path)\", \"fasta\")\nshort_seq_iterator = (record for record in input_seq_iterator if len(record.seq) < $(inputs.minimum_length))\nSeqIO.write(short_seq_iterator, \"$(inputs.sequences.basename).filtered.fasta\", \"fasta\")\n",
                    "prefix": "-c"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).filtered.fasta"
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#discard_short_seqs.cwl/filtered_sequences"
                }
            ],
            "id": "#discard_short_seqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "normalize to fasta",
            "doc": "normalizes input sequeces to FASTA with fixed number of sequence characters\nper line using esl-reformat from https://github.com/EddyRivasLab/easel\n",
            "requirements": [
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#esl-reformat-replace.yaml/replace",
                            "label": "sequence token replacement",
                            "fields": [
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/find",
                                    "type": "string",
                                    "label": null,
                                    "doc": "Must be equal length with \"replace\". Each character from the input file\nwill be replaced by its counterpart (at the same position) from \"replace\"\n"
                                },
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/replace",
                                    "type": "string",
                                    "label": null,
                                    "doc": "must be equal length with \"find\""
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "#esl-reformat-replace.yaml/replace"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--replace",
                        "valueFrom": "$(self.find):$(self.replace)"
                    },
                    "id": "#esl-reformat.cwl/replace"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "format": [
                        "http://edamontology.org/format_1930",
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-reformat.cwl/sequences"
                }
            ],
            "baseCommand": [
                "esl-reformat"
            ],
            "arguments": [
                {
                    "valueFrom": "fasta",
                    "position": 2
                }
            ],
            "stdout": "reformatted_sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-reformat.cwl/reformatted_sequences",
                    "outputBinding": {
                        "glob": "reformatted_sequences"
                    }
                }
            ],
            "id": "#esl-reformat.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10,
                        "valueFrom": "$(self.basename)"
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "cp",
                "$(inputs.sequences.path)",
                "$(runtime.outdir)",
                {
                    "valueFrom": ";",
                    "shellQuote": false
                },
                "esl-sfetch",
                "--index"
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "$(inputs.sequences.format)",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "label": "sequence names to retrieve, one per line",
                    "streamable": true,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "sequences"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "streamable": true,
                    "id": "#extract_coord_lines.cwl/summary"
                }
            ],
            "baseCommand": [
                "grep",
                "-v",
                "^#"
            ],
            "successCodes": [
                0,
                1
            ],
            "stdout": "coord_lines",
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract_coord_lines.cwl/coord_lines",
                    "outputBinding": {
                        "glob": "coord_lines"
                    }
                }
            ],
            "id": "#extract_coord_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "id": "#extract_observations.cwl/tsv_otu_table"
                }
            ],
            "baseCommand": [
                "awk",
                "/#/ {next};{print $1}"
            ],
            "stdin": "$(inputs.tsv_otu_table.path)",
            "stdout": "observations",
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract_observations.cwl/observations",
                    "outputBinding": {
                        "glob": "observations"
                    }
                }
            ],
            "id": "#extract_observations.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#fastq_to_fasta.cwl/fastq"
                }
            ],
            "baseCommand": [
                "python"
            ],
            "arguments": [
                {
                    "valueFrom": "from Bio import SeqIO; SeqIO.convert(\"$(inputs.fastq.path)\", \"fastq\", \"$(inputs.fastq.basename).fasta\", \"fasta\");\n",
                    "prefix": "-c"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.fastq.basename).fasta"
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#fastq_to_fasta.cwl/fasta"
                }
            ],
            "id": "#fastq_to_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005732"
                            ],
                            "version": [
                                "8d53bbce1ffe60d9aa3357c1001599f9a882317a"
                            ],
                            "package": "owltools"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input-file"
                    },
                    "id": "#go_summary.cwl/InterProScan_results"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--config"
                    },
                    "id": "#go_summary.cwl/config"
                }
            ],
            "baseCommand": "go_summary_pipeline-1.0.py",
            "arguments": [
                {
                    "valueFrom": "go-summary",
                    "prefix": "--output-file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "go-summary"
                    },
                    "id": "#go_summary.cwl/go_summary"
                }
            ],
            "id": "#go_summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "report sequences <= this E-value threshold in output",
                    "inputBinding": {
                        "prefix": "-E"
                    },
                    "id": "#hmmsearch.cwl/e_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#hmmsearch.cwl/hmm_profiles"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#hmmsearch.cwl/sequence_query"
                }
            ],
            "baseCommand": [
                "hmmsearch"
            ],
            "arguments": [
                "--domtblout",
                "per_domain_summary.txt",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "per_domain_summary.txt"
                    },
                    "id": "#hmmsearch.cwl/per_domain_summary"
                }
            ],
            "id": "#hmmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/16s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/23s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/5s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/sequences"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/tRNA_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/unique_rRNA_hits"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/unique_tRNA_hits"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "ln",
                "-s",
                "$(inputs.unique_rRNA_hits.path)",
                "nhmmer.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.16s_rRNA_hmmer_matches.path)",
                "nhmmer.16s.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.23s_rRNA_hmmer_matches.path)",
                "nhmmer.23s.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.5s_rRNA_hmmer_matches.path)",
                "nhmmer.5s.txt",
                ";",
                "rnaMaskingStep.py",
                "--hmmer",
                "nhmmer.txt",
                "--nhmmer",
                "$(inputs.unique_tRNA_hits.path)",
                "--seq_id",
                "$(inputs.tRNA_matches.path)",
                "--input",
                "$(inputs.sequences.path)",
                "--output",
                "masked_sequences.fasta"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "masked_sequences.fasta"
                    },
                    "id": "#mask_RNA.cwl/masked_sequences"
                }
            ],
            "id": "#mask_RNA.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "report sequences >= this bit score threshold in output",
                    "inputBinding": {
                        "prefix": "-T"
                    },
                    "id": "#nhmmer.cwl/bitscore_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#nhmmer.cwl/query"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#nhmmer.cwl/sequences"
                }
            ],
            "baseCommand": [
                "nhmmer"
            ],
            "arguments": [
                "--tblout",
                "per_target_summary.txt",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "per_target_summary.txt"
                    },
                    "id": "#nhmmer.cwl/per_target_summary"
                }
            ],
            "id": "#nhmmer.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Post QC-ed input analysis of sequence file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#qc-stats.cwl/QCed_reads"
                },
                {
                    "label": "Prefix for the files associated with GC distribution",
                    "type": "string",
                    "default": "GC-distribution.out",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#qc-stats.cwl/gc_sum"
                },
                {
                    "label": "Prefix for the files assocaited with sequence length distribution",
                    "type": "string",
                    "default": "seq-length.out",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#qc-stats.cwl/length_sum"
                },
                {
                    "label": "Maximum number of sequences to sub-sample",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2000000,
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#qc-stats.cwl/max_seq"
                },
                {
                    "label": "Prefix for the files associated with ucleotide distribution",
                    "type": "string",
                    "default": "nucleotide-distribution.out",
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "id": "#qc-stats.cwl/nucleotide_distribution"
                },
                {
                    "label": "File names for summary of sequences, e.g. number, min/max length etc.",
                    "type": "string",
                    "default": "summary",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#qc-stats.cwl/summary"
                }
            ],
            "baseCommand": [
                "MGRAST_base.py"
            ],
            "outputs": [
                {
                    "label": "Contains the binned GC distribution, real numbers",
                    "type": "File",
                    "format": "#qc-stats.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)_bin"
                    },
                    "id": "#qc-stats.cwl/gc_sum_bin"
                },
                {
                    "label": "Contains all GC fractsions observed and sequence counts",
                    "type": "File",
                    "format": "#qc-stats.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)"
                    },
                    "id": "#qc-stats.cwl/gc_sum_out"
                },
                {
                    "label": "Contains the binned GC distribution, percentage",
                    "type": "File",
                    "format": "#qc-stats.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)_pcbin"
                    },
                    "id": "#qc-stats.cwl/gc_sum_pcbin"
                },
                {
                    "label": "Contains the normalised fraction of nucleotides on the sequences",
                    "type": "File",
                    "format": "#qc-stats.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.nucleotide_distribution)"
                    },
                    "id": "#qc-stats.cwl/nucleotide_distribution_out"
                },
                {
                    "label": "Contains the binned length distribution, real numbers",
                    "type": "File",
                    "format": "#qc-stats.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)_bin"
                    },
                    "id": "#qc-stats.cwl/seq_length_bin"
                },
                {
                    "label": "Contains all the lengths observed and frequencies",
                    "type": "File",
                    "format": "#qc-stats.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)"
                    },
                    "id": "#qc-stats.cwl/seq_length_out"
                },
                {
                    "label": "Contains the binned length distribution expressed as percentage",
                    "type": "File",
                    "format": "#qc-stats.cwl/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)_pcbin"
                    },
                    "id": "#qc-stats.cwl/seq_length_pcbin"
                },
                {
                    "label": "Contains the summary statistics for the input sequence file",
                    "type": "File",
                    "format": "#qc-stats.cwl/text/plain",
                    "outputBinding": {
                        "glob": "$(inputs.summary)"
                    },
                    "id": "#qc-stats.cwl/summary_out"
                }
            ],
            "id": "#qc-stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_008249"
                            ],
                            "version": [
                                "1.9.1"
                            ],
                            "package": "qiime"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "A list of tips (one tip per line) or sequence identifiers (tab-delimited\nlines with a seq identifier in the first field) which should be retained \n",
                    "inputBinding": {
                        "prefix": "--tips_fp=",
                        "separate": false
                    },
                    "id": "#qiime-filter_tree.cwl/tips_or_seqids_to_retain"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input_tree_filepath=",
                        "separate": false
                    },
                    "id": "#qiime-filter_tree.cwl/tree"
                }
            ],
            "baseCommand": "filter_tree.py",
            "arguments": [
                {
                    "valueFrom": "pruned.tree",
                    "prefix": "--output_tree_filepath=",
                    "separate": false
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pruned.tree"
                    },
                    "id": "#qiime-filter_tree.cwl/pruned_tree"
                }
            ],
            "id": "#qiime-filter_tree.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_008249"
                            ],
                            "version": [
                                "1.9.1"
                            ],
                            "package": "qiime"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "--input_fp"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/sequences"
                }
            ],
            "baseCommand": "pick_closed_reference_otus.py",
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "--output_dir"
                },
                "--force"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "log_*.txt"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "otu_table.biom"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/otu_table"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "97_otus.tree"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/otus_tree"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "uclust_ref_picked_otus"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/uclust_ref_picked_otus"
                }
            ],
            "id": "#qiime-pick_closed_reference_otus.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#rRNA_selection.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "rRNA protein model to search with",
                    "id": "#rRNA_selection.cwl/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#rRNA_selection.cwl/hmmsearch/per_domain_summary",
                    "id": "#rRNA_selection.cwl/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rRNA_selection.cwl/fetch_aligned_sequences/sequences",
                    "id": "#rRNA_selection.cwl/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/hmmsearch/per_domain_summary",
                            "id": "#rRNA_selection.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#rRNA_selection.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(18) from (ali coord): The start of the MEA alignment of this\n     domain with respect to the sequence, numbered 1..L for a\n     sequence of L residues.\n(19) to (ali coord): The end of the MEA alignment of this domain\n     with respect to the sequence, numbered 1..L for a sequence of\n     L residues.\n",
                                "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1, $18, $19, $1}"
                        ],
                        "stdout": "formatted_names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "formatted_names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/extract_coord_lines/coord_lines",
                            "id": "#rRNA_selection.cwl/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#rRNA_selection.cwl/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/indexed_sequences",
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#rRNA_selection.cwl/extract_coordinates/formatted_names_and_coords",
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#rRNA_selection.cwl/fetch_aligned_sequences"
                },
                {
                    "run": "#hmmsearch.cwl",
                    "in": [
                        {
                            "default": "1.0E-5",
                            "id": "#rRNA_selection.cwl/hmmsearch/e_threshold"
                        },
                        {
                            "source": "#rRNA_selection.cwl/model",
                            "id": "#rRNA_selection.cwl/hmmsearch/hmm_profiles"
                        },
                        {
                            "source": "#rRNA_selection.cwl/indexed_sequences",
                            "id": "#rRNA_selection.cwl/hmmsearch/sequence_query"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/hmmsearch/per_domain_summary"
                    ],
                    "id": "#rRNA_selection.cwl/hmmsearch"
                }
            ],
            "id": "#rRNA_selection.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#tRNA_selection.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "tRNA model to search with",
                    "id": "#tRNA_selection.cwl/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#tRNA_selection.cwl/nhmmer/per_target_summary",
                    "id": "#tRNA_selection.cwl/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#tRNA_selection.cwl/fetch_aligned_sequences/sequences",
                    "id": "#tRNA_selection.cwl/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/nhmmer/per_target_summary",
                            "id": "#tRNA_selection.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#tRNA_selection.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(7) alifrom: The position in the target sequence at which the hit\n             starts\n(8) ali to: The position in the target sequence at which the hit\n            ends.\n",
                                "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1, $7, $8, $1}"
                        ],
                        "stdout": "formatted_names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "formatted_names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/extract_coord_lines/coord_lines",
                            "id": "#tRNA_selection.cwl/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#tRNA_selection.cwl/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/indexed_sequences",
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#tRNA_selection.cwl/extract_coordinates/formatted_names_and_coords",
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#tRNA_selection.cwl/fetch_aligned_sequences"
                },
                {
                    "run": "#nhmmer.cwl",
                    "in": [
                        {
                            "default": 40,
                            "id": "#tRNA_selection.cwl/nhmmer/bitscore_threshold"
                        },
                        {
                            "source": "#tRNA_selection.cwl/model",
                            "id": "#tRNA_selection.cwl/nhmmer/query"
                        },
                        {
                            "source": "#tRNA_selection.cwl/indexed_sequences",
                            "id": "#tRNA_selection.cwl/nhmmer/sequences"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/nhmmer/per_target_summary"
                    ],
                    "id": "#tRNA_selection.cwl/nhmmer"
                }
            ],
            "id": "#tRNA_selection.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011848"
                            ],
                            "version": [
                                "0.32",
                                "0.35",
                                "0.36"
                            ],
                            "package": "trimmomatic"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#trimmomatic-end_mode.yaml/end_mode",
                            "symbols": [
                                "#trimmomatic-end_mode.yaml/end_mode/SE",
                                "#trimmomatic-end_mode.yaml/end_mode/PE"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-sliding_window.yaml/slidingWindow",
                            "fields": [
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/windowSize",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/requiredQuality",
                                    "type": "int"
                                }
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-phred.yaml/phred",
                            "symbols": [
                                "#trimmomatic-phred.yaml/phred/64",
                                "#trimmomatic-phred.yaml/phred/33"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping",
                            "fields": [
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/adapters",
                                    "type": "File",
                                    "doc": "FASTA file containing adapters, PCR sequences, etc. It is used to search\nfor and remove these sequences in the input FASTQ file(s)\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/seedMismatches",
                                    "type": "int",
                                    "doc": "specifies the maximum mismatch count which will still allow a full match\nto be performed\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/palindromeClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between the two 'adapter ligated' reads\nmust be for PE palindrome read alignment.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/simpleClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between any adapter etc. sequence must\nbe against a read\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/minAdapterLength",
                                    "type": [
                                        "null",
                                        "int"
                                    ],
                                    "doc": "In addition to the alignment score, palindrome mode can verify that a\nminimum length of adapter has been detected. If unspecified, this\ndefaults to 8 bases, for historical reasons. However, since palindrome\nmode has a very low false positive rate, this can be safely reduced, even\ndown to 1, to allow shorter adapter fragments to be removed.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/keepBothReads",
                                    "type": "boolean",
                                    "doc": "After read-though has been detected by palindrome mode, and the adapter\nsequence removed, the reverse read contains the same sequence information\nas the forward read, albeit in reverse complement. For this reason, the\ndefault behaviour is to entirely drop the reverse read. By specifying\n\"true\" for this parameter, the reverse read will also be retained, which\nmay be useful e.g. if the downstream tools cannot handle a combination of\npaired and unpaired reads.  \n"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-max_info.yaml/maxinfo",
                            "fields": [
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/targetLength",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/strictness",
                                    "type": "int"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "AVGQUAL:",
                        "separate": false
                    },
                    "doc": "Drop the read if the average quality is below the specified level\n",
                    "id": "#trimmomatic.cwl/avgqual"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "doc": "Removes bases regardless of quality from the end of the read, so that the\nread has maximally the specified length after this step has been\nperformed. Steps performed after CROP might of course further shorten the\nread. The value is the number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/crop"
                },
                {
                    "type": "#trimmomatic-end_mode.yaml/end_mode",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Single End (SE) or Paired End (PE) mode\n",
                    "id": "#trimmomatic.cwl/end_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "doc": "Removes the specified number of bases, regardless of quality, from the\nbeginning of the read.\nThe numbser specified is the number of bases to keep, from the start of\nthe read.\n",
                    "id": "#trimmomatic.cwl/headcrop"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-illumina_clipping.yaml/illuminaClipping"
                    ],
                    "inputBinding": {
                        "valueFrom": "ILLUMINACLIP:$(self.adapters_file.path):$(self.seedMismatches):$(self.palindromeClipThreshold):$(self.simpleClipThreshold):$(self.minAdapterLength):$(self.keepBothReads)\n",
                        "position": 11
                    },
                    "doc": "Cut adapter and other illumina-specific sequences from the read.",
                    "id": "#trimmomatic.cwl/illuminaClip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list\n(e.g. \"-Xms128m -Xmx512m\")\n",
                    "id": "#trimmomatic.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "doc": "Remove low quality bases from the beginning. As long as a base has a\nvalue below this threshold the base is removed and the next base will be\ninvestigated.\n",
                    "id": "#trimmomatic.cwl/leading"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-max_info.yaml/maxinfo"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "MAXINFO:$(self.targetLength):$(strictness)\n"
                    },
                    "doc": "Performs an adaptive quality trim, balancing the benefits of retaining\nlonger reads against the costs of retaining bases with errors.\n<targetLength>: This specifies the read length which is likely to allow\nthe location of the read within the target sequence to be determined.\n<strictness>: This value, which should be set between 0 and 1, specifies\nthe balance between preserving as much read length as possible vs.\nremoval of incorrect bases. A low value of this parameter (<0.2) favours\nlonger reads, while a high value (>0.8) favours read correctness.\n",
                    "id": "#trimmomatic.cwl/maxinfo"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 100,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "doc": "This module removes reads that fall below the specified minimal length.\nIf required, it should normally be after all other processing steps.\nReads removed by this step will be counted and included in the \"dropped\nreads\" count presented in the trimmomatic summary.\n",
                    "id": "#trimmomatic.cwl/minlen"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-threads"
                    },
                    "doc": "Number of threads",
                    "id": "#trimmomatic.cwl/nthreads"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-phred.yaml/phred"
                    ],
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 4
                    },
                    "doc": "\"33\" or \"64\" specifies the base quality encoding. Default: 64\n",
                    "id": "#trimmomatic.cwl/phred"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "FASTQ file of reads (R1 reads in Paired End mode)",
                    "id": "#trimmomatic.cwl/reads1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "FASTQ file of R2 reads in Paired End mode",
                    "id": "#trimmomatic.cwl/reads2"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-sliding_window.yaml/slidingWindow"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "SLIDINGWINDOW:$(self.windowSize):$(self.requiredQuality)\n"
                    },
                    "doc": "Perform a sliding window trimming, cutting once the average quality\nwithin the window falls below a threshold. By considering multiple\nbases, a single poor quality base will not cause the removal of high\nquality data later in the read.\n<windowSize> specifies the number of bases to average across\n<requiredQuality> specifies the average quality required\n",
                    "id": "#trimmomatic.cwl/slidingwindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.",
                    "id": "#trimmomatic.cwl/tophred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.",
                    "id": "#trimmomatic.cwl/tophred64"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "doc": "Remove low quality bases from the end. As long as a base has a value\nbelow this threshold the base is removed and the next base (which as\ntrimmomatic is starting from the 3' prime end would be base preceding\nthe just removed base) will be investigated. This approach can be used\nremoving the special Illumina \"low quality segment\" regions (which are\nmarked with quality score of 2), but we recommend Sliding Window or\nMaxInfo instead\n",
                    "id": "#trimmomatic.cwl/trailing"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trim.log"
                    },
                    "label": "Trimmomatic log",
                    "doc": "log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n",
                    "id": "#trimmomatic.cwl/output_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).trimmed.fastq"
                    },
                    "id": "#trimmomatic.cwl/reads1_trimmed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).unpaired.trimmed.fastq"
                    },
                    "id": "#trimmomatic.cwl/reads1_trimmed_unpaired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#trimmomatic.cwl/reads2_trimmed_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.unpaired.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#trimmomatic.cwl/reads2_trimmed_unpaired"
                }
            ],
            "baseCommand": [
                "java",
                "org.usadellab.trimmomatic.Trimmomatic"
            ],
            "arguments": [
                {
                    "valueFrom": "trim.log",
                    "prefix": "-trimlog",
                    "position": 4
                },
                {
                    "valueFrom": "$(inputs.reads1.nameroot).trimmed.fastq",
                    "position": 7
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads1.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 8
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 9
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 10
                }
            ],
            "doc": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop\nIllumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem\ndepending on the library preparation and downstream application.\nThere are two major modes of the program: Paired end mode and Single end mode. The\npaired end mode will maintain correspondence of read pairs and also use the additional\ninformation contained in paired reads to better find adapter or PCR primer fragments\nintroduced by the library preparation process.\nTrimmomatic works with FASTQ files (using phred + 33 or phred + 64 quality scores,\ndepending on the Illumina pipeline used).\n",
            "id": "#trimmomatic.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Functional analyis of sequences that match the 16S SSU",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#16S_taxonomic_analysis.cwl/16S_matches"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/result",
                    "id": "#16S_taxonomic_analysis.cwl/biom_json"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/create_otu_text_summary/otu_table_summary",
                    "id": "#16S_taxonomic_analysis.cwl/otu_table_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/prune_tree/pruned_tree",
                    "id": "#16S_taxonomic_analysis.cwl/tree"
                }
            ],
            "steps": [
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/biom"
                        },
                        {
                            "default": "taxonomy",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/header_key"
                        },
                        {
                            "default": "OTU table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/table_type"
                        },
                        {
                            "default": true,
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/tsv"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/result"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic"
                },
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/biom"
                        },
                        {
                            "default": true,
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/json"
                        },
                        {
                            "default": "OTU table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/table_type"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/result"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom"
                },
                {
                    "run": "#biom-summarize_table.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                            "id": "#16S_taxonomic_analysis.cwl/create_otu_text_summary/biom"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/create_otu_text_summary/otu_table_summary"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/create_otu_text_summary"
                },
                {
                    "run": "#extract_observations.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/result",
                            "id": "#16S_taxonomic_analysis.cwl/extract_observations/tsv_otu_table"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/extract_observations/observations"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/extract_observations"
                },
                {
                    "run": "#qiime-pick_closed_reference_otus.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/16S_matches",
                            "id": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/sequences"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                        "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otus_tree"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus"
                },
                {
                    "run": "#qiime-filter_tree.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/extract_observations/observations",
                            "id": "#16S_taxonomic_analysis.cwl/prune_tree/tips_or_seqids_to_retain"
                        },
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otus_tree",
                            "id": "#16S_taxonomic_analysis.cwl/prune_tree/tree"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/prune_tree/pruned_tree"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/prune_tree"
                }
            ],
            "id": "#16S_taxonomic_analysis.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "EMG pipeline v3.0 (single end version)",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        },
                        {
                            "$import": "#trimmomatic-sliding_window.yaml/slidingWindow"
                        },
                        {
                            "$import": "#trimmomatic-end_mode.yaml/end_mode"
                        },
                        {
                            "$import": "#trimmomatic-phred.yaml/phred"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/16S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/23S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/5S_model"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#main/fraggenescan_model"
                },
                {
                    "type": "File",
                    "id": "#main/go_summary_config"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/tRNA_model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/16S_taxonomic_analysis/biom_json",
                    "id": "#main/biom_json"
                },
                {
                    "type": "File",
                    "outputSource": "#main/functional_analysis/functional_annotations",
                    "id": "#main/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#main/functional_analysis/go_summary",
                    "id": "#main/go_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/16S_taxonomic_analysis/otu_table_summary",
                    "id": "#main/otu_table_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/ORF_prediction/predictedCDS",
                    "id": "#main/predicted_CDS"
                },
                {
                    "type": "File",
                    "outputSource": "#main/find_SSUs_and_mask/masked_sequences",
                    "id": "#main/processed_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sequence_stats/gc_sum_out",
                    "id": "#main/qc_stats_gc"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sequence_stats/gc_sum_bin",
                    "id": "#main/qc_stats_gc_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sequence_stats/gc_sum_pcbin",
                    "id": "#main/qc_stats_gc_pcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sequence_stats/nucleotide_distribution_out",
                    "id": "#main/qc_stats_nuc_dist"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sequence_stats/seq_length_out",
                    "id": "#main/qc_stats_seq_len"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sequence_stats/seq_length_bin",
                    "id": "#main/qc_stats_seq_len_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sequence_stats/seq_length_pcbin",
                    "id": "#main/qc_stats_seq_len_pbcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sequence_stats/summary_out",
                    "id": "#main/qc_stats_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/16S_taxonomic_analysis/tree",
                    "id": "#main/tree"
                }
            ],
            "steps": [
                {
                    "doc": "16s rRNA are annotated using the Greengenes reference database\n(default closed-reference OTU picking protocol with Greengenes\n13.8 reference with reverse strand matching enabled).\n",
                    "run": "#16S_taxonomic_analysis.cwl",
                    "in": [
                        {
                            "source": "#main/find_SSUs_and_mask/16S_matches",
                            "id": "#main/16S_taxonomic_analysis/16S_matches"
                        }
                    ],
                    "out": [
                        "#main/16S_taxonomic_analysis/otu_table_summary",
                        "#main/16S_taxonomic_analysis/tree",
                        "#main/16S_taxonomic_analysis/biom_json"
                    ],
                    "id": "#main/16S_taxonomic_analysis"
                },
                {
                    "doc": "Find reads with predicted coding sequences (pCDS) above 60 nucleotides in\nlength.\n",
                    "run": "#FragGeneScan1_20.cwl",
                    "in": [
                        {
                            "default": false,
                            "id": "#main/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#main/fraggenescan_model",
                            "id": "#main/ORF_prediction/model"
                        },
                        {
                            "source": "#main/find_SSUs_and_mask/masked_sequences",
                            "id": "#main/ORF_prediction/sequence"
                        }
                    ],
                    "out": [
                        "#main/ORF_prediction/predictedCDS"
                    ],
                    "id": "#main/ORF_prediction"
                },
                {
                    "run": "#clean_fasta_headers.cwl",
                    "in": [
                        {
                            "source": "#main/convert_trimmed-reads_to_fasta/fasta",
                            "id": "#main/clean_fasta_headers/sequences"
                        }
                    ],
                    "out": [
                        "#main/clean_fasta_headers/sequences_with_cleaned_headers"
                    ],
                    "id": "#main/clean_fasta_headers"
                },
                {
                    "run": "#fastq_to_fasta.cwl",
                    "in": [
                        {
                            "source": "#main/trim_quality_control/reads1_trimmed",
                            "id": "#main/convert_trimmed-reads_to_fasta/fastq"
                        }
                    ],
                    "out": [
                        "#main/convert_trimmed-reads_to_fasta/fasta"
                    ],
                    "id": "#main/convert_trimmed-reads_to_fasta"
                },
                {
                    "run": "#rna-selector.cwl",
                    "in": [
                        {
                            "source": "#main/16S_model",
                            "id": "#main/find_SSUs_and_mask/16S_model"
                        },
                        {
                            "source": "#main/23S_model",
                            "id": "#main/find_SSUs_and_mask/23S_model"
                        },
                        {
                            "source": "#main/5S_model",
                            "id": "#main/find_SSUs_and_mask/5S_model"
                        },
                        {
                            "source": "#main/clean_fasta_headers/sequences_with_cleaned_headers",
                            "id": "#main/find_SSUs_and_mask/reads"
                        },
                        {
                            "source": "#main/tRNA_model",
                            "id": "#main/find_SSUs_and_mask/tRNA_model"
                        }
                    ],
                    "out": [
                        "#main/find_SSUs_and_mask/16S_matches",
                        "#main/find_SSUs_and_mask/masked_sequences"
                    ],
                    "id": "#main/find_SSUs_and_mask"
                },
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro. \n",
                    "run": "#functional_analysis.cwl",
                    "in": [
                        {
                            "source": "#main/go_summary_config",
                            "id": "#main/functional_analysis/go_summary_config"
                        },
                        {
                            "source": "#main/ORF_prediction/predictedCDS",
                            "id": "#main/functional_analysis/predicted_CDS"
                        }
                    ],
                    "out": [
                        "#main/functional_analysis/functional_annotations",
                        "#main/functional_analysis/go_summary"
                    ],
                    "id": "#main/functional_analysis"
                },
                {
                    "run": "#qc-stats.cwl",
                    "in": [
                        {
                            "source": "#main/clean_fasta_headers/sequences_with_cleaned_headers",
                            "id": "#main/sequence_stats/QCed_reads"
                        }
                    ],
                    "out": [
                        "#main/sequence_stats/summary_out",
                        "#main/sequence_stats/seq_length_pcbin",
                        "#main/sequence_stats/seq_length_bin",
                        "#main/sequence_stats/seq_length_out",
                        "#main/sequence_stats/nucleotide_distribution_out",
                        "#main/sequence_stats/gc_sum_pcbin",
                        "#main/sequence_stats/gc_sum_bin",
                        "#main/sequence_stats/gc_sum_out"
                    ],
                    "id": "#main/sequence_stats"
                },
                {
                    "doc": "Low quality trimming (low quality ends and sequences with < quality scores\nless than 15 over a 4 nucleotide wide window are removed)\n",
                    "run": "#trimmomatic.cwl",
                    "in": [
                        {
                            "default": "SE",
                            "id": "#main/trim_quality_control/end_mode"
                        },
                        {
                            "default": 3,
                            "id": "#main/trim_quality_control/leading"
                        },
                        {
                            "default": 100,
                            "id": "#main/trim_quality_control/minlen"
                        },
                        {
                            "default": "33",
                            "id": "#main/trim_quality_control/phred"
                        },
                        {
                            "source": "#main/reads",
                            "id": "#main/trim_quality_control/reads1"
                        },
                        {
                            "default": {
                                "windowSize": 4,
                                "requiredQuality": 15
                            },
                            "id": "#main/trim_quality_control/slidingwindow"
                        },
                        {
                            "default": 3,
                            "id": "#main/trim_quality_control/trailing"
                        }
                    ],
                    "out": [
                        "#main/trim_quality_control/reads1_trimmed"
                    ],
                    "id": "#main/trim_quality_control"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "functional analysis prediction with InterProScan",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#functional_analysis.cwl/go_summary_config"
                },
                {
                    "type": "File",
                    "id": "#functional_analysis.cwl/predicted_CDS"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/functional_analysis/i5Annotations",
                    "id": "#functional_analysis.cwl/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/summarize_with_GO/go_summary",
                    "id": "#functional_analysis.cwl/go_summary"
                }
            ],
            "steps": [
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro. \n",
                    "run": "#InterProScan5.21-60.cwl",
                    "in": [
                        {
                            "default": [
                                "Pfam",
                                "TIGRFAM",
                                "PRINTS",
                                "ProSitePatterns",
                                "Gene3D"
                            ],
                            "id": "#functional_analysis.cwl/functional_analysis/applications"
                        },
                        {
                            "source": "#functional_analysis.cwl/remove_asterisks_and_reformat/reformatted_sequences",
                            "id": "#functional_analysis.cwl/functional_analysis/proteinFile"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/functional_analysis/i5Annotations"
                    ],
                    "id": "#functional_analysis.cwl/functional_analysis"
                },
                {
                    "run": "#esl-reformat.cwl",
                    "in": [
                        {
                            "default": {
                                "find": "*",
                                "replace": "X"
                            },
                            "id": "#functional_analysis.cwl/remove_asterisks_and_reformat/replace"
                        },
                        {
                            "source": "#functional_analysis.cwl/predicted_CDS",
                            "id": "#functional_analysis.cwl/remove_asterisks_and_reformat/sequences"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/remove_asterisks_and_reformat/reformatted_sequences"
                    ],
                    "id": "#functional_analysis.cwl/remove_asterisks_and_reformat"
                },
                {
                    "doc": "A summary of Gene Ontology (GO) terms derived from InterPro matches to\nthe sample. It is generated using a reduced list of GO terms called\nGO slim (http://www.geneontology.org/ontology/subsets/goslim_metagenomics.obo)\n",
                    "run": "#go_summary.cwl",
                    "in": [
                        {
                            "source": "#functional_analysis.cwl/functional_analysis/i5Annotations",
                            "id": "#functional_analysis.cwl/summarize_with_GO/InterProScan_results"
                        },
                        {
                            "source": "#functional_analysis.cwl/go_summary_config",
                            "id": "#functional_analysis.cwl/summarize_with_GO/config"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/summarize_with_GO/go_summary"
                    ],
                    "id": "#functional_analysis.cwl/summarize_with_GO"
                }
            ],
            "id": "#functional_analysis.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "RNASelector as a CWL workflow",
            "doc": "https://doi.org/10.1007/s12275-011-1213-z",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#trimmomatic-sliding_window.yaml/slidingWindow"
                        },
                        {
                            "$import": "#trimmomatic-end_mode.yaml/end_mode"
                        },
                        {
                            "$import": "#trimmomatic-phred.yaml/phred"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#rna-selector.cwl/16S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#rna-selector.cwl/23S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#rna-selector.cwl/5S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#rna-selector.cwl/reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#rna-selector.cwl/tRNA_model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#rna-selector.cwl/discard_short_16S_matches/filtered_sequences",
                    "id": "#rna-selector.cwl/16S_matches"
                },
                {
                    "type": "File",
                    "outputSource": "#rna-selector.cwl/mask_rRNA_and_tRNA/masked_sequences",
                    "id": "#rna-selector.cwl/masked_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#collate_unique_SSU_headers.cwl",
                    "in": [
                        {
                            "source": [
                                "#rna-selector.cwl/find_16S_matches/hmmer_search_results",
                                "#rna-selector.cwl/find_23S_matches/hmmer_search_results",
                                "#rna-selector.cwl/find_5S_matches/hmmer_search_results"
                            ],
                            "id": "#rna-selector.cwl/collate_unique_rRNA_hmmer_hits/hits"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/collate_unique_rRNA_hmmer_hits/unique_hits"
                    ],
                    "id": "#rna-selector.cwl/collate_unique_rRNA_hmmer_hits"
                },
                {
                    "run": "#collate_unique_SSU_headers.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/find_tRNA_matches/hmmer_search_results",
                            "valueFrom": "${ return [ self ]; }",
                            "id": "#rna-selector.cwl/collate_unique_tRNA_hmmer_hits/hits"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/collate_unique_tRNA_hmmer_hits/unique_hits"
                    ],
                    "id": "#rna-selector.cwl/collate_unique_tRNA_hmmer_hits"
                },
                {
                    "run": "#discard_short_seqs.cwl",
                    "in": [
                        {
                            "default": 80,
                            "id": "#rna-selector.cwl/discard_short_16S_matches/minimum_length"
                        },
                        {
                            "source": "#rna-selector.cwl/find_16S_matches/matching_sequences",
                            "id": "#rna-selector.cwl/discard_short_16S_matches/sequences"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/discard_short_16S_matches/filtered_sequences"
                    ],
                    "id": "#rna-selector.cwl/discard_short_16S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/find_16S_matches/indexed_sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/16S_model",
                            "id": "#rna-selector.cwl/find_16S_matches/model"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/find_16S_matches/matching_sequences",
                        "#rna-selector.cwl/find_16S_matches/hmmer_search_results"
                    ],
                    "id": "#rna-selector.cwl/find_16S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/find_23S_matches/indexed_sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/23S_model",
                            "id": "#rna-selector.cwl/find_23S_matches/model"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/find_23S_matches/matching_sequences",
                        "#rna-selector.cwl/find_23S_matches/hmmer_search_results"
                    ],
                    "id": "#rna-selector.cwl/find_23S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/find_5S_matches/indexed_sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/5S_model",
                            "id": "#rna-selector.cwl/find_5S_matches/model"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/find_5S_matches/matching_sequences",
                        "#rna-selector.cwl/find_5S_matches/hmmer_search_results"
                    ],
                    "id": "#rna-selector.cwl/find_5S_matches"
                },
                {
                    "run": "#tRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/find_tRNA_matches/indexed_sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/tRNA_model",
                            "id": "#rna-selector.cwl/find_tRNA_matches/model"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/find_tRNA_matches/matching_sequences",
                        "#rna-selector.cwl/find_tRNA_matches/hmmer_search_results"
                    ],
                    "id": "#rna-selector.cwl/find_tRNA_matches"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/reads",
                            "id": "#rna-selector.cwl/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/index_reads/sequences_with_index"
                    ],
                    "id": "#rna-selector.cwl/index_reads"
                },
                {
                    "run": "#mask_RNA.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/find_16S_matches/hmmer_search_results",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/16s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#rna-selector.cwl/find_23S_matches/hmmer_search_results",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/23s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#rna-selector.cwl/find_5S_matches/hmmer_search_results",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/5s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/find_tRNA_matches/hmmer_search_results",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/tRNA_matches"
                        },
                        {
                            "source": "#rna-selector.cwl/collate_unique_rRNA_hmmer_hits/unique_hits",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/unique_rRNA_hits"
                        },
                        {
                            "source": "#rna-selector.cwl/collate_unique_tRNA_hmmer_hits/unique_hits",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/unique_tRNA_hits"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/mask_rRNA_and_tRNA/masked_sequences"
                    ],
                    "id": "#rna-selector.cwl/mask_rRNA_and_tRNA"
                }
            ],
            "id": "#rna-selector.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
